@@ -11,14 +11,21 @@ from dataclasses import dataclass, field
 
 ND2_VARS = json.loads(os.environ['ND2_VARS'])
 
+
 @dataclass(frozen=True)
 class StashManager:
     store: dict = field(default_factory=dict)
 
     def get(self, key):
-        return ND2_VARS[key] or self.store[key]
+        if key in ND2_VARS:
+            return ND2_VARS[key]
+        elif key in self.store:
+            return self.store[key]
+        else:
+            raise KeyError(f'cannot find key "{key}" in Perl/Dancer vars or Python stash')
 
     def set(self, key, val):
         self.store[key] = val
 
-stash = StashManager()
\ No newline at end of file
+
+stash = StashManager()
